OC.L10N.register(
    "forms",
    {
    "Copy" : "Kopieer",
    "Shared with you" : "Met u gedeel",
    "Cancel" : "Cancel",
    "Required" : "Vereis",
    "Delete" : "Skrap",
    "Other" : "Ander",
    "Set expiration date" : "Stel vervaldatum",
    "Group" : "Groep",
    "Share link" : "Deel skakel",
    "Add link" : "Voeg skakel toe",
    "Internal link" : "Interne skakel",
    "View" : "Bekyk",
    "Edit" : "Wysig",
    "View mode" : "Lysaansig",
    "Share" : "Deel",
    "Description" : "Beskrywing",
    "Summary" : "Opsomming",
    "Download" : "Laai af",
    "Search" : "Soek",
    "Settings" : "Instellings",
    "Submit" : "Dien in",
    "File" : "Lêer",
    "Date" : "Datum",
    "Time" : "Tyd",
    "Color" : "Kleur",
    "Text" : "Teks",
    "Phone number" : "Foonnommer",
    "Email address" : "E-posadres",
    "Uploading …" : "Laai tans op …"
},
"nplurals=2; plural=(n != 1);");
